A function that checks if a call to simulation function worked
Source:R/check_simresults.R
check_simresults.RdThis function takes the return from a call to a simulate_ function and checks that no errors occured. If something goes wrong, an error message is returned