Skip to contents

This function opens a Shiny app with a menu that will allow the user to run the different simulations.

Usage

dsairmmenu()

Details

Run this function with no arguments to start the main menu (a Shiny app) for DSAIRM.

Author

Andreas Handel

Examples

if (FALSE) dsairmmenu() # \dontrun{}