A helper function that produces a call to a simulator function for specific settings
Source:R/generate_fctcall.R
generate_fctcall.RdThis function takes a modelsettings structure and uses that information to create an unevaluated function call that runs the simulator function with the specified settings