Daily average virus load of volunteers infected with influenza.
Usage
data(hayden96flu)Format
A data frame with these variables:
- HoursPI
Hours post infection - measurements were taken daily.
- txtime
Hours post infection when treatment started. The value of 29 is the average of the 2 reported early treatment times. A value of 200, which is later than the last recorded virus load, means no treatment.
- LogVirusLoad
Average virus load for volunteers in a given treatment condition, in log10 units.
- LOD
Limit of detection for virus load, in log10 units.