R/check_simresults.R
check_simresults.RdThis function takes the return from a call to a simulate_ function and checks that no errors occured. If something goes wrong, an error message is returned
check_simresults(simresult)Ane error message string or NULL
This function checks simulation results generated from a single call to a simulate_ function.