R/generate_fctcall.R
generate_fctcall.RdThis function takes a modelsettings structure and uses that information to create an unevaluated function call that runs the simulator function with the specified settings
generate_fctcall(modelsettings)A string containing an unevaluated function call with the specified settings, or an error message
This function produces a function call for specific settings.